function [sys,x0,str,ts] = nzdesign(t,x,u,flag,n_a,n_b,n_r,A_m,A_o,A_r,A_s,h);

%NZDESIGN M-file S-function performing minimum-degree pole-placement design
% without zero cancellation
%
% inputs: u = [B,A], B and A polynomials
% outputs: R,S and T polynomials
% parameters: n_a, deg A; n_b, deg B; n_r, deg R; A_m, desired
% closed-loop polynomial; A_o observer polynomial; A_r A_s
% pre-determined factors in R and S; h, sampling interval
% 


switch flag,

  %%%%%%%%%%%%%%%%%%
  % Initialization %
  %%%%%%%%%%%%%%%%%%
  case 0,
    [sys,x0,str,ts] = mdlInitializeSizes(n_a,n_b,n_r,h);
  %%%%%%%%%%
  % Update %
  %%%%%%%%%%
  case 2,                                                
    sys = mdlUpdate; 

  %%%%%%%%%%
  % Output %
  %%%%%%%%%%
  case 3,                                                
    sys = mdlOutputs(u,n_b,A_m,A_o,A_r,A_s);

  %%%%%%%%%%%%%
  % Terminate %
  %%%%%%%%%%%%%
  case 9,                                                
    sys = []; % do nothing

  %%%%%%%%%%%%%%%%%%%%
  % Unexpected flags %
  %%%%%%%%%%%%%%%%%%%%
  otherwise
    error(['unhandled flag = ',num2str(flag)]);
end

%end dsfunc



%=======================================================================
% mdlInitializeSizes
% Return the sizes, initial conditions, and sample times for the S-function.
%=======================================================================
%
function [sys,x0,str,ts] = mdlInitializeSizes(n_a,n_b,n_r,h)

sizes = simsizes;
sizes.NumContStates  = 0;
sizes.NumDiscStates  = 0;
sizes.NumOutputs     = 3*(n_r+1);
sizes.NumInputs      = (n_a+1) + (n_b+1);
sizes.DirFeedthrough = 1;
sizes.NumSampleTimes = 1;

sys = simsizes(sizes);

x0  = [];
str = [];
ts  = [h 0]; 

% end mdlInitializeSizes
%
%=======================================================================
% mdlUpdate
% Handle discrete state updates, sample time hits, and major time step
% requirements.
%=======================================================================
%
function sys = mdlUpdate

sys = [];

%end mdlUpdate
%
%=======================================================================
% mdlOutputs
% Return Return the output vector for the S-function
%=======================================================================
%
function sys = mdlOutputs(u,n_b,A_m,A_o,A_r,A_s)

B = u(1:n_b+1)';
A = u(n_b+2:end)';
 
[R,S,T]=rstd(1,B,A,1,A_m,A_o,A_r,A_s);
sys = [R,S,T]';

%end mdlUpdate


